@@ -2,7 +2,7 @@
 # vc-dwim - a version-control-agnostic ChangeLog diff and commit tool
 # @configure_input@
 #
-# Copyright 2006-2009 Free Software Foundation, Inc.
+# Copyright 2006-2010 Free Software Foundation, Inc.
 # Written by Jim Meyering <meyering@redhat.com>
 
 # This program is free software: you can redistribute it and/or modify
@@ -311,7 +311,7 @@ sub run_command
 
   if ($options{INHIBIT_STDERR})
     {
-      open SAVE_ERR, ">&STDERR";
+      open SAVE_ERR, '>&', STDERR;
       open STDERR, ">/dev/null"
         or die "$ME: cannot redirect stderr to /dev/null: $!\n";
       select STDERR; $| = 1;
@@ -321,9 +321,9 @@ sub run_command
   my $rc = 0xffff & system @cmd;
 
   # Restore stdout.
-  open STDOUT, ">&SAVE_OUT"
+  open STDOUT, '>&', SAVE_OUT
     if $options{INHIBIT_STDOUT};
-  open STDERR, ">&SAVE_ERR"
+  open STDERR, '>&', SAVE_ERR
     if $options{INHIBIT_STDERR};
 
   if ($rc == 0)
@@ -558,7 +558,7 @@ sub do_commit ($$$$)
     {
      DEBUG => $debug,
      VERBOSE => $verbose,
-     DIE_UPON_FAILURE => 0,
+     DIE_UPON_FAILURE => 1,
      INHIBIT_STDOUT => 0,
     };
   run_command ($options, @cmd);
@@ -1051,11 +1051,11 @@ sub main
 
       if ($symlinked_changelog)
         {
+          do_commit $vc, $author, \@log_msg_lines, [@affected_files];
           do_at (dirname ($symlinked_changelog),
                  sub { do_commit ($vc_changelog, $author,
                                   ['non-empty-commit-msg'],
                                   [basename ($symlinked_changelog)])});
-          do_commit $vc, $author, \@log_msg_lines, [@affected_files];
         }
       else
         {
